Crate kcode_speaker_model
kcode_
speaker_
model
0.2.1
All Items
Crate Items
Structs
Enums
Constants
Functions
Crate
kcode_
speaker_
model
Structs

Candidate
Score
FitInput
FitRows
Input
A minimal fitting request for callers that do not own media provenance.
Identification
Model
Config
Model
Snapshot
Training
Row
The complete model input needed for one labelled feature row.
Enums

Decision
Model
Error
Constants

ALL_24
Functions

decode
encode
fit
fit_
rows
Fits the same deterministic model from only IDs and feature vectors.
identify